==> walkers-fabric-1.18.2-4.5-sources.jar: tocraft/walkers/ability/impl/WitchAbility.java <==
package tocraft.walkers.ability.impl;

import tocraft.walkers.ability.ShapeAbility;

import java.util.Arrays;
import java.util.List;
import net.minecraft.class_1308;
import net.minecraft.class_1657;
import net.minecraft.class_1686;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1842;
import net.minecraft.class_1844;
import net.minecraft.class_1847;
import net.minecraft.class_1937;
import net.minecraft.class_243;
import net.minecraft.class_3417;

public class WitchAbility<T extends class_1308> extends ShapeAbility<T> {

    public static final List<class_1842> VALID_POTIONS = Arrays.asList(class_1847.field_9004, class_1847.field_8982, class_1847.field_8996, class_1847.field_8975);

    @Override
    public void onUse(class_1657 player, T shape, class_1937 world) {
        class_1686 potionEntity = new class_1686(world, player);
        potionEntity.method_16940(class_1844.method_8061(new class_1799(class_1802.field_8436), VALID_POTIONS.get(world.field_9229.nextInt(VALID_POTIONS.size()))));
        potionEntity.method_36457(-20.0F);
        class_243 rotation = player.method_5720();
        potionEntity.method_7485(rotation.method_10216(), rotation.method_10214(), rotation.method_10215(), 0.75F, 8.0F);

        world.method_8465(null, player.method_23317(), player.method_23318(), player.method_23321(), class_3417.field_15067, player.method_5634(), 1.0F, 0.8F + world.field_9229.nextFloat() * 0.4F);

        world.method_8649(potionEntity);
    }

    @Override
    public class_1792 getIcon() {
        return class_1802.field_8574;
    }

    @Override
    public int getDefaultCooldown() {
        return 200;
    }
}

==> walkers-fabric-1.20.2-4.4.1-sources.jar: tocraft/walkers/ability/impl/WitchAbility.java <==
package tocraft.walkers.ability.impl;

import tocraft.walkers.ability.ShapeAbility;

import java.util.Arrays;
import java.util.List;
import net.minecraft.class_1308;
import net.minecraft.class_1657;
import net.minecraft.class_1686;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1842;
import net.minecraft.class_1844;
import net.minecraft.class_1847;
import net.minecraft.class_1937;
import net.minecraft.class_243;
import net.minecraft.class_3417;

public class WitchAbility<T extends class_1308> extends ShapeAbility<T> {

    public static final List<class_1842> VALID_POTIONS = Arrays.asList(class_1847.field_9004, class_1847.field_8982, class_1847.field_8996, class_1847.field_8975);

    @Override
    public void onUse(class_1657 player, T shape, class_1937 world) {
        class_1686 potionEntity = new class_1686(world, player);
        potionEntity.method_16940(class_1844.method_8061(new class_1799(class_1802.field_8436), VALID_POTIONS.get(world.field_9229.method_43048(VALID_POTIONS.size()))));
        potionEntity.method_36457(-20.0F);
        class_243 rotation = player.method_5720();
        potionEntity.method_7485(rotation.method_10216(), rotation.method_10214(), rotation.method_10215(), 0.75F, 8.0F);

        world.method_43128(null, player.method_23317(), player.method_23318(), player.method_23321(), class_3417.field_15067, player.method_5634(), 1.0F, 0.8F + world.field_9229.method_43057() * 0.4F);

        world.method_8649(potionEntity);
    }

    @Override
    public class_1792 getIcon() {
        return class_1802.field_8574;
    }

    @Override
    public int getDefaultCooldown() {
        return 200;
    }
}
